:py:mod:`piel.cli`
==================

.. py:module:: piel.cli

.. autoapi-nested-parse::

   Console script for piel.



Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.cli.main



.. py:function:: main(args=None)

   Console script for piel.
